/*
PhysicalComputingDemonstrations.h - Physical Computing for Lectures library
Created by Miguel Angel Rubio - marubio@ugr.es
date: June 2014

Copyright (C) 2014  Miguel Angel Rubio

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or any 
later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program. If not, see http://www.gnu.org/licenses/ .

    Feel free to mail me if bugs or new ideas!
*/



#ifndef PHYSICAL_COMPUTING_DEMONSTRATIONS_H_
#define PHYSICAL_COMPUTING_DEMONSTRATIONS_H_

#include <Arduino.h>
//Limitations of Arduino IDE...
#include "../Servo/Servo.h" 

/////////////////////////////////////
// Read Voltage
//////////////////////////////////////

int lee_voltaje(int num_pin)
{
    int valor;
    valor = analogRead(num_pin);

    return valor;
}

/////////////////////////////////////
// Turn off LEDs
//////////////////////////////////////

// Turn off a single LED

void apaga_led(int num_led)
{
    pinMode(num_led, OUTPUT);
    digitalWrite(num_led, LOW);
}

// Turn off multiple LEDs

void apaga_led(int num_led[], int size_led)
{
    for (int cont = 0; cont < size_led; cont++){
        pinMode(num_led[cont], OUTPUT);
        digitalWrite(num_led[cont], LOW);
        }
}

/////////////////////////////////////
// Turn on LEDs
//////////////////////////////////////

// Turn on a single LED

void enciende_led(int num_led)
{
    pinMode(num_led, OUTPUT);
    digitalWrite(num_led, HIGH);
}

// Turn on multiple LEDs

void enciende_led(int num_led[], int size_led)
{
    for (int cont = 0; cont < size_led; cont++){
        pinMode(num_led[cont], OUTPUT);
        digitalWrite(num_led[cont], HIGH);
        }
}


/////////////////////////////////////
// Move Servo
//////////////////////////////////////

// Move servo to a certain position
// It assumes the servo is plugged in 

void mover_servo(Servo mi_servo, int posicion)
{
    mi_servo.write(posicion);   
}

/////////////////////////////////////
// Pause for some seconds
//////////////////////////////////////

void para (float segundos)
{
    delay(segundos*1000);
}

/////////////////////////////////
// Read temperature
///////////////////////////////////

// Reads temperatura using Arduino.
// The sensor is TMP36 from the Arduino Starter Kit
// Inpunt analog_pin: The pin that is going to be used to read the temperature
// Output: The temperature

int lee_temperatura(int analog_pin){
 
 char str[256];

 // We perform 20 measurements to minimize error rate.
 float temp = 0;
 float temp = 0;
 int num_medidas = 20;
 float voltaje;
 
 for (int cont = 0; cont < 20; cont++) {
    voltaje = lee_voltaje(analog_pin); //Medida directa
    voltaje = voltaje*5/1024; //Voltaje normalizado
    temp= temp+voltaje/0.01 - 50; //En C
 }

 // Take the mean
 int temperatura = temp/num_medidas;
 return temperatura;
 
}

/////////////////////////////////
// Read brightness
///////////////////////////////////

// See the brightness fo the room
// Th sensor is LDR-VT90N2 
// See the pdf attached
// Input analog_pin: The pin that is going to be used to read the brightness
// Output: The value of brightness normalized between 0 and 1

float lee_luminosidad (int analog_pin){
  float voltaje = lee_voltaje(analog_pin);
  voltaje = voltaje/1024.;
  return voltaje;
}

#endif // PHYSICAL_COMPUTING_DEMONSTRATIONS_H_